@@ -528,7 +528,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 35734984 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 35971671 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -865,6 +865,18 @@ if [ $? -ne 0 ]; then
     exit 1
 fi
 
+# Make sure we can create temp files.  Check TMPDIR (POSIX-compliant) if present
+[ -z "$TMPDIR" ] && TMPDIR="/tmp"
+tmptest="$TMPDIR/nvbrtesttemp.$$"
+touch "$tmptest"
+if [ $? -ne 0 ]; then
+    echo "ERROR: The directory $TMPDIR is not writable.  Please set TMPDIR"
+    echo "       to a directory with write permission for temporary output files"
+    exit 1
+else
+    rm -f "$tmptest"
+fi
+
 
 # print a start message to stdout
 
@@ -1625,7 +1637,7 @@ done
         if [ $? -eq 0 -a -x "$base64" ]; then
             # make sure what we can write to the temp file
 
-            NVDD_TEMP_FILENAME="nvidia-debugdump-temp$$.log"
+            NVDD_TEMP_FILENAME="$TMPDIR/nvidia-debugdump-temp$$.log"
 
             touch $NVDD_TEMP_FILENAME 2> /dev/null
 
@@ -1856,7 +1868,7 @@ fi
 
         if [ $? -eq 0 -a -x "$base64" ]; then
 
-            TEMP_FILENAME="acpidump-temp$$.log"
+            TEMP_FILENAME="$TMPDIR/acpidump-temp$$.log"
 
             echo "$acpidump -o"
             echo ""
@@ -1885,13 +1897,8 @@ fi
 ) | $GZIP_CMD >> $LOG_FILENAME
 
 dump_mlx() {
-    if [ -z "${TMPDIR}" ]; then
-        tmp_dir="/tmp"
-    else
-        tmp_dir="${TMPDIR}"
-    fi
-    MLX_CSV="$tmp_dir/mlx$$.csv"
-    MLX_INFO="$tmp_dir/mlx$$.info"
+    MLX_CSV="$TMPDIR/mlx$$.csv"
+    MLX_INFO="$TMPDIR/mlx$$.info"
     # mlxlink --amber_collect file will dump information to the specified csv file, and
     # print information to stdout (in color).
     # Capture both and remove the color escape characters.
